# Licensed under a 3-clause BSD style license - see LICENSE.rst
# -*- coding: utf-8 -*-


from asdf.yamlutil import custom_tree_to_tagged_tree

from astropy.time import TimeDelta
from astropy.time.tests.test_delta import (allclose_jd, allclose_jd2,
                                           allclose_sec)

from ...types import AstropyType


__all__ = ['TimeDeltaType']


class TimeDeltaType(AstropyType):
    name = 'time/timedelta'
    types = [TimeDelta]
    version = '1.0.0'


    @classmethod
    def to_tree(cls, obj, ctx):
        return custom_tree_to_tagged_tree(obj.info._represent_as_dict(), ctx)


    @classmethod
    def from_tree(cls, node, ctx):
        return TimeDelta.info._construct_from_dict(node)


    @classmethod
    def assert_equal(cls, old, new):
        assert allclose_jd(old.jd, new.jd)
        assert allclose_jd2(old.jd2, new.jd2)
        assert allclose_sec(old.sec, new.sec)



# Licensed under a 3-clause BSD style license - see LICENSE.rst
# -*- coding: utf-8 -*-

from astropy.units.equivalencies import Equivalency
from astropy.units import equivalencies
from astropy.units.quantity import Quantity
from asdf.yamlutil import custom_tree_to_tagged_tree

from astropy.io.misc.asdf.types import AstropyType


class EquivalencyType(AstropyType):
    name = "units/equivalency"
    types = [Equivalency]
    version = '1.0.0'

    @classmethod
    def to_tree(cls, equiv, ctx):
        node = {}
        if not isinstance(equiv, Equivalency):
            raise TypeError("'{0}' is not a valid Equivalency".format(equiv))

        eqs = []
        for e, kwargs in zip(equiv.name, equiv.kwargs):
            kwarg_names = list(kwargs.keys())
            kwarg_values = list(kwargs.values())
            kwarg_values = [custom_tree_to_tagged_tree(val, ctx) if isinstance(val, Quantity)
                            else val for val in kwarg_values]
            eq = {'name': e, 'kwargs_names': kwarg_names, 'kwargs_values': kwarg_values}
            eqs.append(eq)
        return eqs

    @classmethod
    def from_tree(cls, node, ctx):
        eqs = []
        for eq in node:
            equiv = getattr(equivalencies, eq['name'])
            kwargs = dict(zip(eq['kwargs_names'], eq['kwargs_values']))
            eqs.append(equiv(**kwargs))
        return sum(eqs[1:], eqs[0])

    @classmethod
    def assert_equal(cls, a, b):
        assert a == b



# Autogenerated by Astropy's setup.py on 2019-06-15 04:46:19 UTC
from __future__ import unicode_literals
import datetime

version = "3.2.1"
githash = "3c27d0619e05ab4289587b61197f2b0b6ec38288"


major = 3
minor = 2
bugfix = 1

version_info = (major, minor, bugfix)

release = True
timestamp = datetime.datetime(2019, 6, 15, 4, 46, 19)
debug = False

astropy_helpers_version = "3.2.1"
